function x = gauss_elimination_w_pivoting(A, b)
    % Augmented matrix
    augmented_matrix = [A b];

    % Number of equations
    n = size(A, 1);

    disp('initial augmented matrix')
    augmented_matrix

    % Gaussian Elimination with Partial Pivoting (forward elimination)
    for i = 1:n-1
        % Partial pivoting: Find the row with the maximum element in the current column
        [~, max_row] = max(abs(augmented_matrix(i:n,i)));
        max_row = max_row + i - 1;

        % Swap rows if necessary
        if max_row ~= i
            temp = augmented_matrix(i,:);
            augmented_matrix(i,:) = augmented_matrix(max_row,:);
            augmented_matrix(max_row,:) = temp;
        end

        % Perform elimination as usual
        for j = i+1:n
            factor = augmented_matrix(j,i) / augmented_matrix(i,i);
            augmented_matrix(j,:) = augmented_matrix(j,:) - factor * augmented_matrix(i,:);
        end

        disp('elimination augmented matrix')
        augmented_matrix
    end

    % Back substitution
    x = zeros(n,1);
    x(n) = augmented_matrix(n,end) / augmented_matrix(n,n);

    for i = n-1:-1:1
        x(i) = (augmented_matrix(i,end) - augmented_matrix(i,i+1:n) * x(i+1:n)) / augmented_matrix(i,i);
    end

    disp('final augmented matrix')
    augmented_matrix
end

